@@ -1,5 +1,5 @@
 class Device():
-    def __init__(self, name, description, primaryIP4Id, primaryIP4Address, serialNumber, locationId, locationName, siteId, siteName, organizationId, organizationName, rackId, rackFace, id, netBoxId):
+    def __init__(self, name, description, primaryIP4Id, primaryIP4Address, serialNumber, locationId, locationName, siteId, siteName, organizationId, organizationName, rackId, rackFace, id, netBoxId, validFrom, validTo, isActive):
         self.name = name
         self.description = description
         self.primaryIP4Id = primaryIP4Id
@@ -13,6 +13,9 @@ class Device():
         self.organizationName = organizationName
         self.rackId = rackId
         self.rackFace = rackFace
+        self.validFrom = validFrom
+        self.validTo = validTo
+        self.isActive = isActive
         self.id = id
 
         self.netBoxId = netBoxId
